(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@nativescript/angular'), require('@nativescript/core'), require('rxjs/operators'), require('@ngrx/store-devtools')) :
  typeof define === 'function' && define.amd ? define('ngrx-devtools-nativescript', ['exports', '@angular/core', '@nativescript/angular', '@nativescript/core', 'rxjs/operators', '@ngrx/store-devtools'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ngrx-devtools-nativescript'] = {}, global.ng.core, global.angular, global.core$1, global.rxjs.operators, global.storeDevtools));
}(this, (function (exports, core, angular, core$1, operators, storeDevtools) { 'use strict';

  var TOGGLE_BTN_HEIGHT = 40;
  var NSDockMonitor = /** @class */ (function () {
      function NSDockMonitor(page) {
          this.page = page;
          this.screenCover = 0.5;
          this.shown = false;
          this.toggleLength = TOGGLE_BTN_HEIGHT;
      }
      NSDockMonitor.prototype.ngAfterViewInit = function () {
          this.toggleBtn = this.toggleBtnEl.nativeElement;
      };
      NSDockMonitor.prototype.dockLoaded = function (args) {
          var _this = this;
          this.dock = args.object;
          setTimeout(function () { return _this.setup(); }, 100);
      };
      NSDockMonitor.prototype.setup = function () {
          var height = this.dock.getActualSize().height;
          console.log("Dock height: " + height);
          this.offsetHidden = height - this.toggleLength;
          this.offsetShown = height * this.screenCover - this.toggleLength;
          this.dock.height = this.offsetHidden - this.offsetShown + this.toggleLength;
          this.dock.animate({ translate: { x: 0, y: this.offsetHidden } });
      };
      NSDockMonitor.prototype.toggleShown = function () {
          this.shown = !this.shown;
          if (this.shown) {
              this.toggleBtn.animate({ rotate: 180 });
              this.dock.animate({ translate: { x: 0, y: this.offsetShown } });
          }
          else {
              this.toggleBtn.animate({ rotate: 0 });
              this.dock.animate({ translate: { x: 0, y: this.offsetHidden } });
          }
      };
      return NSDockMonitor;
  }());
  NSDockMonitor.decorators = [
      { type: core.Component, args: [{
                  selector: 'ns-dock-monitor',
                  changeDetection: core.ChangeDetectionStrategy.OnPush,
                  template: "\n    <grid-layout rows=\"auto *\" #dock class=\"dock\" rowSpan=\"100\" colSpan=\"100\" translateY=\"1000\" (loaded)=\"dockLoaded($event)\">\n      <label text=\"^\" (tap)=\"toggleShown()\" #toggle [width]=\"toggleLength\" [height]=\"toggleLength\" class=\"toggle\"></label>\n      <grid-layout row=\"1\">\n        <ns-log-monitor></ns-log-monitor>\n      </grid-layout>\n    </grid-layout>\n  ",
                  styles: ["\n    .toggle {\n        color: white;\n        border-radius:" + TOGGLE_BTN_HEIGHT / 2 + ";\n        border-width: 2;\n        border-color: #69737D;\n        background-color: #2A2F3A;\n        text-align: center;\n        font-family: monospace;\n        font-size: 32;\n        font-weight: bold;\n    }\n    .dock {\n        vertical-align: top;\n    }\n  "]
              },] }
  ];
  NSDockMonitor.ctorParameters = function () { return [
      { type: core$1.Page }
  ]; };
  NSDockMonitor.propDecorators = {
      screenCover: [{ type: core.Input }],
      toggleBtnEl: [{ type: core.ViewChild, args: ["toggle", { static: false },] }],
      dockEl: [{ type: core.ViewChild, args: ["dock", { static: false },] }]
  };

  var NSLogMonitor = /** @class */ (function () {
      function NSLogMonitor(devtools) {
          this.devtools = devtools;
          this.canRevert$ = devtools.liftedState.pipe(operators.map(function (s) { return !(s.computedStates.length > 1); }));
          this.canSweep$ = devtools.liftedState.pipe(operators.map(function (s) { return !(s.skippedActionIds.length > 0); }));
          this.canCommit$ = devtools.liftedState.pipe(operators.map(function (s) { return !(s.computedStates.length > 1); }));
          this.items$ = devtools.liftedState.pipe(operators.map(function (_a) {
              var actionsById = _a.actionsById, skippedActionIds = _a.skippedActionIds, stagedActionIds = _a.stagedActionIds, computedStates = _a.computedStates;
              var actions = [];
              for (var i = 0; i < stagedActionIds.length; i++) {
                  var actionId = stagedActionIds[i];
                  var action = actionsById[actionId].action;
                  var _b = computedStates[i], state = _b.state, error = _b.error;
                  var previousState = void 0;
                  if (i > 0) {
                      previousState = computedStates[i - 1].state;
                  }
                  actions.push({
                      key: actionId,
                      collapsed: skippedActionIds.indexOf(actionId) > -1,
                      action: action,
                      actionId: actionId,
                      state: state,
                      previousState: previousState,
                      error: error
                  });
              }
              return actions.slice(1);
          }));
      }
      NSLogMonitor.prototype.handleToggle = function (id) {
          this.devtools.toggleAction(id);
      };
      NSLogMonitor.prototype.handleReset = function () {
          this.devtools.reset();
      };
      NSLogMonitor.prototype.handleRollback = function () {
          this.devtools.rollback();
      };
      NSLogMonitor.prototype.handleSweep = function () {
          this.devtools.sweep();
      };
      NSLogMonitor.prototype.handleCommit = function () {
          this.devtools.commit();
      };
      return NSLogMonitor;
  }());
  NSLogMonitor.decorators = [
      { type: core.Component, args: [{
                  selector: 'ns-log-monitor',
                  changeDetection: core.ChangeDetectionStrategy.OnPush,
                  template: "\n    <grid-layout rows=\"auto *\" class=\"container\">\n      <stack-layout orientation=\"horizontal\" class=\"toolbar\">\n        <log-monitor-button text=\"Reset\" (action)=\"handleReset()\">\n        </log-monitor-button>\n\n        <log-monitor-button text=\"Revert\" (action)=\"handleRollback()\" [disabled]=\"canRevert$ | async\">\n        </log-monitor-button>\n\n        <log-monitor-button text=\"Sweep\"(action)=\"handleSweep()\" [disabled]=\"canSweep$ | async\">\n        </log-monitor-button>\n\n        <log-monitor-button text=\"Commit\" (action)=\"handleCommit()\" [disabled]=\"canCommit$ | async\">\n        </log-monitor-button>\n      </stack-layout>\n\n      <scroll-view row=\"1\">\n        <stack-layout class=\"items\">\n          <log-monitor-entry\n            *ngFor=\"let item of (items$ | async); let even = even\"\n            [even]=\"even\"\n            [item]=\"item\"\n            (toggle)=\"handleToggle($event.id)\">\n          </log-monitor-entry>\n        </stack-layout>\n      </scroll-view>\n    </grid-layout>\n  ",
                  styles: ["\n    .container {\n      background-color: #2A2F3A;\n      font-family: monospace;\n    }\n\n    .toolbar {\n      horizontal-align: center;\n      height: 32;\n    }\n\n    .items {\n      background-color: #69737D;\n      horizontal-align: stretch;\n    }\n  "]
              },] }
  ];
  NSLogMonitor.ctorParameters = function () { return [
      { type: storeDevtools.StoreDevtools }
  ]; };

  var logSuffixCount = 0;
  var LogMonitorEntry = /** @class */ (function () {
      function LogMonitorEntry() {
          this.toggle = new core.EventEmitter();
      }
      LogMonitorEntry.prototype.handleToggle = function () {
          this.toggle.next({ id: this.item.actionId });
      };
      LogMonitorEntry.prototype.logPayload = function () {
          console.log("ACTION: " + JSON.stringify(this.item.action) + this.logSuffix());
      };
      LogMonitorEntry.prototype.logState = function () {
          console.log("STATE: " + JSON.stringify(this.item.state) + this.logSuffix());
      };
      LogMonitorEntry.prototype.logSuffix = function () {
          // IOS console stacks same messages. Add an " " suffix on every second message to prevent that.
          if (core$1.isIOS) {
              return (logSuffixCount++ % 2) ? "" : " ";
          }
          else {
              return "";
          }
      };
      return LogMonitorEntry;
  }());
  LogMonitorEntry.decorators = [
      { type: core.Component, args: [{
                  selector: 'log-monitor-entry',
                  changeDetection: core.ChangeDetectionStrategy.OnPush,
                  encapsulation: core.ViewEncapsulation.Emulated,
                  template: "\n    <grid-layout columns=\"* auto\" class=\"container\" [class.even]=\"even\">\n      <grid-layout (tap)=\"handleToggle()\">\n        <label [text]=\"item.action.type\"\n              class=\"title-bar\"\n              [class.collapsed]=\"item.collapsed\"></label>\n      </grid-layout>\n\n      <stack-layout col=\"1\" *ngIf=\"!item.collapsed\" orientation=\"horizontal\">\n        <log-monitor-button (action)=\"logPayload()\" text=\"Log Payload\">\n        </log-monitor-button>\n\n        <log-monitor-button (action)=\"logState()\" text=\"Log State\">\n        </log-monitor-button>\n      </stack-layout>\n    </grid-layout>\n  ",
                  styles: ["\n    .container {\n      horizontal-align: stretch;\n      height: 32;\n    }\n    .title-bar {\n      text-align: left;\n      horizontal-align: stretch;\n      vertical-align: center;\n      margin: 6 10;\n      font-family: monosapce;\n      color: #FFFFFF;\n      font-size: 12;\n      font-weight: bold;\n    }\n    .collapsed{\n      text-decoration: line-through;\n      font-style: italic;\n      opacity: 0.5;\n    }\n    .even {\n      background-color: #7A8590;\n    }\n  "]
              },] }
  ];
  LogMonitorEntry.propDecorators = {
      item: [{ type: core.Input }],
      even: [{ type: core.Input }],
      toggle: [{ type: core.Output }]
  };

  var LogMonitorButton = /** @class */ (function () {
      function LogMonitorButton() {
          this.action = new core.EventEmitter();
          this.text = "";
      }
      LogMonitorButton.prototype.handleAction = function () {
          if (!this.disabled) {
              this.action.next({});
          }
      };
      return LogMonitorButton;
  }());
  LogMonitorButton.decorators = [
      { type: core.Component, args: [{
                  selector: 'log-monitor-button',
                  changeDetection: core.ChangeDetectionStrategy.OnPush,
                  encapsulation: core.ViewEncapsulation.Emulated,
                  template: "\n  <button [text]=\"text\" (tap)=\"handleAction()\" [class.disabled]=\"disabled\"></button>",
                  styles: ["\n     button {\n      font-family: monospace;\n      font-weight: bold;\n      border-radius: 3;\n      margin: 5 3;\n      padding: 3 5;\n      font-size: 10;\n      color: white;\n      background-color: #4F5A65;\n    }\n\n    .disabled{\n      opacity: 0.2;\n      background-color: transparent;\n    }\n  "]
              },] }
  ];
  LogMonitorButton.propDecorators = {
      disabled: [{ type: core.Input }],
      action: [{ type: core.Output }],
      text: [{ type: core.Input }]
  };

  var NativeScriptDevToolsMonitors = /** @class */ (function () {
      function NativeScriptDevToolsMonitors() {
      }
      return NativeScriptDevToolsMonitors;
  }());
  NativeScriptDevToolsMonitors.decorators = [
      { type: core.NgModule, args: [{
                  declarations: [LogMonitorEntry, LogMonitorButton, NSLogMonitor, NSDockMonitor],
                  imports: [angular.NativeScriptModule],
                  exports: [NSDockMonitor],
                  schemas: [core.NO_ERRORS_SCHEMA],
              },] }
  ];

  /*
   * Public API Surface of ngrx-devtools-nativescript
   */

  /**
   * Generated bundle index. Do not edit.
   */

  exports.NativeScriptDevToolsMonitors = NativeScriptDevToolsMonitors;
  exports.ɵa = LogMonitorEntry;
  exports.ɵb = LogMonitorButton;
  exports.ɵc = NSLogMonitor;
  exports.ɵd = NSDockMonitor;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngrx-devtools-nativescript.umd.js.map
